=======
History
=======

0.2.1 (2018-1-4)

* Bugfix: Custom template definitions were not properly respecting context definitions

0.2.0 (2017-12-6)
------------------

* Template definitions and transpilers have been made composable with custom
context definitions in order to simplify the YML for people who use languages
other than Python

* Constants for Context option names have been included

0.1.0 (2017-02-12)
------------------

* First release on PyPI.
